//Simulate a RBC model + capital utilization + GHH utility + Capital adjuustment cost against a news shock
// lizhaorui@pku.edu.cn
// Last version: 2021/6/11
var y logy c logc i logi k logk k_m logk_m e loge n logn w logw r logr a lambda loglambda mu logmu;
varexo e_a e_u;
parameters alph betta phi gam delt delt0 thetta rho sigma_a sigma_u s;
alph = 1/3;
betta = 0.99;
delt = 0.025;
gam = 0.4;
rho = 0.90;
sigma_a = 0.01;
sigma_u  = 0.01;
s = 1.15 ; % s =0 no investment adjustment cost %1.15, if there is investment adjustment cost

model;
[name = 'production function']
y = exp(a)*e^alph*k(-1)^alph*n^(1-alph);
[name = 'technology']
a = rho*a(-1) + e_a + e_u(-4);
[name = 'capital accumulation']
k = (1-delt0*e^(1+thetta)/(1+thetta))*k(-1) + i*(1 - s/2*(i/i(-1) - 1)^2);
[name = 'labor demand']
(1-alph)*y/n = w;
[name = 'labor supply']
phi*n^gam = w;
[name = 'consumption']
1/(c - phi*n^(1+gam)/(1+gam)) = lambda;
[name = 'investment']
lambda = mu*(1-s/2-3*s/2*(i/i(-1))^2 + 2*s*(i/i(-1))) + betta*mu(+1)*s*(i(+1)/i-1)*(i(+1)/i)^2;
[name = 'capital utilization']
lambda*r = mu*delt0*e^(1+thetta);
% e =1; % No captial utilization
[name = 'capital demand']
alph*y/k(-1)=r;
[name = 'capital supply']
mu = betta*(lambda(+1)*r(+1) + mu(+1)*(1-delt0*e(+1)^(1+thetta)/(1+thetta)));
[name = 'resource constraint']
y = c + i + s/2*(i/i(-1)-1)^2;
[name = 'capital in the model']
k_m = k(-1);
logy = 100*log(y);
logc = 100*log(c);
logi = 100*log(i);
logk = 100*log(k);
logn = 100*log(n);
logw = 100*log(w);
logr = 100*log(r);
loge = 100*log(e);
logk_m = 100*log(k_m);
loglambda = 100*log(lambda);
logmu = 100*log(mu);
end;

steady_state_model;
%calibration target
n = 1/3;
e =1;
%calibration
yk = (1/betta - 1 + delt)/alph;
delt0 =alph*yk;
thetta = delt0/delt - 1;
ck = yk - delt;
e = 1;
nk = yk^(1/(1-alph));
k = n/nk;
c = k*ck;
y = k*yk;
i = delt*k;
phi = n^(-gam)*(1-alph)*nk^(-alph);
k_m = k;
w =(1-alph)*y/n;
r = alph*yk;
logy = 100*log(y);
logc = 100*log(c);
logi = 100*log(i);
logk = 100*log(k);
logn = 100*log(n);
logw = 100*log(w);
logr = 100*log(r);
loge = 100*log(e);
logk_m = 100*log(k_m);
lambda = 1/(c-phi*n^(1+gam)/(1+gam));
loglambda = 100*log(lambda);
mu = lambda;
logmu = 100*log(mu);
end;

shocks;
%var e_a = sigma_a^2;
var e_u = sigma_u^2;
end;

stoch_simul(order = 1,irf=10) logy logc logi logk_m loge logn logw logr a;
%stoch_simul(order = 1,irf=10) logy logc logi logk_m loge logn logw logr a loglambda logmu;
