% In this question we revisit expectation-driven business cycles models (i.e. news shock). 
% The model is a simplified version of one-sector model in Jaimovich & Rebelo (2009) taken from Wang (2012).
% This is an extension that we shut down the GHH channel. 
% songkaihong@pku.edu.cn. First version: 2021/06/08


% steady state has changed, in FOC eqn for N and for ii. Adding GHH has
% remove the income-effect, which can make labor comoves with y, c, k, ii.
% If we remove GHH, then the agg effect depends on the parameters or
% calibration.

% In this model, we find we still have comovement, but the magnitude is
% much smaller than previous.


var y, logy, c, logc, k, logk, n, logn, ii, logii, A, logA, e, loge, vlambda, vdelta;
varexo eps, u;
parameters pbeta, pgamma, ppsi, palpha, pdelta0, ptheta, prho, psigmaa, psigmau, ps;

pbeta = 0.99;
pgamma = 0.4;
ppsi =  4.069934618381792;
palpha = 1/3;
pdelta0 = 0.035101010101010105;
ptheta = 0.40404040404040403;
% undetermined
prho = 0.66; 
psigmaa = .01;
psigmau = .01;
ps = 1.15;

model; % 8 equations should be here
[name = 'eqn 1']
c+ii=A*(e*k(-1))^palpha*n^(1-palpha);

[name = 'eqn y']
y=A*(e*k(-1))^palpha*n^(1-palpha);

[name = 'eqn 3']
vdelta = pdelta0*e^(1+ptheta)/(1+ptheta); % eqn 3

[name = 'eqn 2']
k = ii*(1-ps/2*(ii/ii(-1)-1)^2)+(1-vdelta)*k(-1);

[name = 'eqn 5']
logA = prho*logA(-1)+eps+u(-4);

[name = 'FOC ii'] % changed
1/(c)= pbeta*vlambda(1)*(ii(1)/ii)^2*ps*(ii(1)/ii-1)+vlambda*(1-ps/2*(ii/ii(-1)-1)^2-ii/ii(-1)*ps*(ii/ii(-1)-1));

[name = 'FOC k'] % changed
vlambda = pbeta*(palpha*A(1)*(e(1)*k)^(palpha-1)*n(1)^(1-palpha)*e(1)/c(1)+ vlambda(1)*(1-vdelta(1)));

[name = 'FOC e'] % checked
(palpha*A*(e*k(-1))^(palpha-1)*n^(1-palpha)*k(-1))/(c)=vlambda*k(-1)*pdelta0*e^ptheta;

[name = 'FOC n']
ppsi*n^pgamma = (1-palpha)*A*(e*k(-1))^palpha*n^(-palpha)/c;

logy = 100*log(y);
logc = 100*log(c);
logk = 100*log(k);
logn = 100*log(n);
logii = 100*log(ii);
logA = 100*log(A);
loge = 100*log(e);
end;

initval;
% steady_state_model;
y = 1.02721; n = 1/3; k = 9.75478; 
c = 0.783338; ii = 0.243869;
A = 1; e = 1; vdelta = 0.025;
vlambda = 1.27659;
logy = 100*log(y);
logc = 100*log(c);
logk = 100*log(k);
logn = 100*log(n);
logii = 100*log(ii);
logA = 100*log(A);
loge = 100*log(e);
end;

steady;
check;

shocks;
var eps = psigmaa^2;
var u = psigmau^2;
end;

stoch_simul(order = 1,irf=40) logy logn logc logii logk logA loge; %y n c ii k A e;