% In this question we revisit expectation-driven business cycles models (i.e. news shock). 
% The model is a simplified version of one-sector model in Jaimovich & Rebelo (2009) taken from Wang (2012).
% songkaihong@pku.edu.cn. First version: 2021/06/08

% In this case we rule out the variable utilization of capital. 

var y, logy, c, logc, k, logk, n, logn, ii, logii, A, logA, e, loge, vlambda, vdelta;
varexo eps, u;
parameters pbeta, pgamma, ppsi, palpha, pdelta0, ptheta, prho, psigmaa, psigmau, ps;

pbeta = 0.99;
pgamma = 0.4;
ppsi = 3.1881357723383354;
palpha = 1/3;
pdelta0 = 0.035101010101010105;
ptheta = 0.40404040404040403;
% undetermined
prho = 0.66; 
psigmaa = .01;
psigmau = .01;
ps = 1.15;

model; % 8 equations should be here
[name = 'eqn constant e']
e = 1;

[name = 'eqn 1']
c+ii=A*(e*k(-1))^palpha*n^(1-palpha);

[name = 'eqn y']
y=A*(e*k(-1))^palpha*n^(1-palpha);

[name = 'eqn 3']
vdelta = pdelta0*e^(1+ptheta)/(1+ptheta); % eqn 3

[name = 'eqn 2']
k = ii*(1-ps/2*(ii/ii(-1)-1)^2)+(1-vdelta)*k(-1);

[name = 'eqn 5']
logA = prho*logA(-1)+eps+u(-4);

[name = 'FOC ii'] % checked
1/(c-ppsi*n^(1+pgamma)/(1+pgamma))= pbeta*vlambda(1)*(ii(1)/ii)^2*ps*(ii(1)/ii-1)
+vlambda*(1-ps/2*(ii/ii(-1)-1)^2-ii/ii(-1)*ps*(ii/ii(-1)-1));

[name = 'FOC k'] % checked
vlambda = pbeta*(palpha*A(1)*(e*k)^(palpha-1)*n(1)^(1-palpha)*e/(c(1)-ppsi*n(1)^(1+pgamma)/(1+pgamma))+ vlambda(1)*(1-vdelta(1)));

[name = 'FOC n']
ppsi*n^pgamma = (1-palpha)*A*(e*k(-1))^palpha*n^(-palpha);

logy = 100*log(y);
logc = 100*log(c);
logk = 100*log(k);
logn = 100*log(n);
logii = 100*log(ii);
logA = 100*log(A);
loge = 100*log(e);
end;

initval;
% steady_state_model;
y = 1.02721; n = 1/3; k = 9.75478; 
c = 0.783338; ii = 0.243869;
A = 1; vdelta = 0.025;
vlambda = 3.39914;
e = 1;
logy = 100*log(y);
logc = 100*log(c);
logk = 100*log(k);
logn = 100*log(n);
logii = 100*log(ii);
logA = 100*log(A);
loge = 100*log(e);
end;

steady;
check;

shocks;
var eps = psigmaa^2;
var u = psigmau^2;
end;

stoch_simul(order = 2,irf=40) logy logn logc logii logk logA loge; %y n c ii k A e;